#!/usr/bin/env python3


from libervia.server.constants import Const as C
from sat.core.i18n import _, D_
from sat.core.log import getLogger
from sat.tools.common import data_format

log = getLogger(__name__)

name = "forum_view"
label = D_("View")
access = C.PAGES_ACCESS_PUBLIC
template = "forum/view.html"


def parse_url(self, request):
    self.get_path_args(request, ["service", "node"], 2, service="jid")


async def prepare_render(self, request):
    data = self.get_r_data(request)
    data["show_comments"] = False
    blog_page = self.get_page_by_name("blog_view")
    request.args[b"before"] = [b""]
    request.args[b"reverse"] = [b"1"]
    await blog_page.prepare_render(self, request)
    request.template_data["login_url"] = self.get_page_redirect_url(request)


async def on_data_post(self, request):
    profile = self.get_profile(request)
    if profile is None:
        self.page_error(request, C.HTTP_FORBIDDEN)
    type_ = self.get_posted_data(request, "type")
    if type_ == "comment":
        service, node, body = self.get_posted_data(request, ("service", "node", "body"))

        if not body:
            self.page_error(request, C.HTTP_BAD_REQUEST)
        mb_data = {"content_rich": body}
        try:
            await self.host.bridge_call(
                "mb_send", service, node, data_format.serialise(mb_data), profile)
        except Exception as e:
            if "forbidden" in str(e):
                self.page_error(request, 401)
            else:
                raise e
    else:
        log.warning(_("Unhandled data type: {}").format(type_))
